@@ -51,26 +51,26 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 compiler="gcc"
 
-qt_version=5.6.1
+qt_version=5.6.2
 zlib_version=1.2.8
 zlib_patchlevel=2
 libogg_version=1.3.2
 libogg_patchlevel=1
 libvorbis_version=1.3.5
 libvorbis_patchlevel=3
-ffmpeg_version=3.0.1
-ffmpeg_patchlevel=3
+ffmpeg_version=3.2.2
+ffmpeg_patchlevel=1
 #libav_version=11.4
 #libav_patchlevel=2
 libflac_version=1.3.1
 libflac_patchlevel=4
 id3lib_version=3.8.3
 id3lib_patchlevel=16.2
-taglib_version=1.11
-chromaprint_version=1.3
-chromaprint_patchlevel=1
+taglib_version=1.11.1
+chromaprint_version=1.3.2
+chromaprint_patchlevel=2
 mp4v2_version=2.0.0
-mp4v2_patchlevel=4
+mp4v2_patchlevel=5
 
 FLAC_BUILD_OPTION="--enable-debug"
 ID3LIB_BUILD_OPTION="--enable-debug=minimum"
@@ -82,6 +82,13 @@ CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=RelWithDebInfo"
 #AV_BUILD_OPTION="--enable-debug=3"
 #CMAKE_BUILD_OPTION="-DCMAKE_BUILD_TYPE=Debug"
 
+# Uncomment for a LINUX_SELF_CONTAINED build
+#export CC="gcc-4.7"
+#export CXX="g++-4.7"
+#export CFLAGS="-O2 -fPIC"
+#export CXXFLAGS="-O2 -fPIC"
+#AV_BUILD_OPTION="$AV_BUILD_OPTION --enable-pic --extra-ldexeflags=-pie"
+
 if ! which cmake >/dev/null; then
   echo cmake not found.
   return
@@ -108,6 +115,13 @@ cross_host="i686-w64-mingw32"
 CONFIGURE_OPTIONS="--host=${cross_host}"
 fi
 
+if test $kernel = "MINGW" || test "$compiler" = "cross-mingw"; then
+  # Build zlib only for Windows.
+  ZLIB_ROOT_PATH="$thisdir/zlib-$zlib_version/inst/usr/local"
+  TAGLIB_ZLIB_ROOT_OPTION="-DZLIB_ROOT=${ZLIB_ROOT_PATH}"
+  CHROMAPRINT_ZLIB_OPTION="-DEXTRA_LIBS=\"-L${ZLIB_ROOT_PATH}/lib -lz\""
+fi
+
 if test $kernel = "Darwin"; then
 ARCH=$(uname -m)
 #ARCH=i386
@@ -196,10 +210,12 @@ $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/libv/libvorbis/libvorbis_${l
 test -f taglib-${taglib_version}.tar.gz ||
 $DOWNLOAD http://taglib.github.io/releases/taglib-${taglib_version}.tar.gz
 
+if test -n "$ZLIB_ROOT_PATH"; then
 test -f zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg-${zlib_patchlevel}.debian.tar.xz
 test -f zlib_${zlib_version}.dfsg.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg.orig.tar.gz
+fi
 
 if test -n "${ffmpeg_version}"; then
 test -f ffmpeg_${ffmpeg_version}.orig.tar.xz ||
@@ -234,27 +250,31 @@ $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_versio
 
 # Create patch files
 
-if test "$compiler" = "cross-mingw"; then
-test -f mingw.cmake ||
-cat >mingw.cmake <<EOF
+if test "$compiler" = "cross-mingw" && ! test -f mingw.cmake; then
+  for d in $thisdir/qtbase5-dev-tools* /usr/lib/${HOSTTYPE/i686/i386}-linux-gnu/qt5/bin /usr/bin; do
+    if test -x $d/moc; then
+      _qt_bin_dir=$d
+      break
+    fi
+  done
+  cat >mingw.cmake <<EOF
 set(QT_PREFIX /windows/Qt/Qt${qt_version}/${qt_version%.?}/mingw49_32)
 
 set(CMAKE_SYSTEM_NAME Windows)
 set(CMAKE_C_COMPILER ${cross_host}-gcc)
 set(CMAKE_CXX_COMPILER ${cross_host}-g++)
 set(CMAKE_RC_COMPILER ${cross_host}-windres)
-set(CMAKE_FIND_ROOT_PATH /usr/${cross_host} \${QT_PREFIX} $thisdir/buildroot/usr/local $thisdir/zlib-$zlib_version/inst/usr/local $thisdir/$ffmpeg_dir/inst/usr/local)
+set(CMAKE_FIND_ROOT_PATH /usr/${cross_host} \${QT_PREFIX} $thisdir/buildroot/usr/local ${ZLIB_ROOT_PATH} $thisdir/$ffmpeg_dir/inst/usr/local)
 set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
 set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
 set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
 
-set(QT_BINARY_DIR /usr/lib/${HOSTTYPE/i686/i386}-linux-gnu/qt5/bin)
+set(QT_BINARY_DIR ${_qt_bin_dir})
 set(QT_LIBRARY_DIR  \${QT_PREFIX}/lib)
 set(QT_QTCORE_LIBRARY   \${QT_PREFIX}/lib/libQt5Core.a)
 set(QT_QTCORE_INCLUDE_DIR \${QT_PREFIX}/include/QtCore)
 set(QT_MKSPECS_DIR  \${QT_PREFIX}/mkspecs)
 set(QT_MOC_EXECUTABLE  \${QT_BINARY_DIR}/moc)
-set(QT_QMAKE_EXECUTABLE  \${QT_BINARY_DIR}/qmake)
 set(QT_UIC_EXECUTABLE  \${QT_BINARY_DIR}/uic)
 
 foreach (_exe moc rcc lupdate lrelease uic)
@@ -546,6 +566,152 @@ cat >taglib_bvreplace.patch <<"EOF"
  }
 EOF
 
+test -f taglib_mp4shwm.patch ||
+cat >taglib_mp4shwm.patch <<"EOF"
+diff --git a/taglib/mp4/mp4tag.cpp b/taglib/mp4/mp4tag.cpp
+index a8e2e7d..0c2e5cb 100644
+--- a/taglib/mp4/mp4tag.cpp
++++ b/taglib/mp4/mp4tag.cpp
+@@ -71,10 +71,10 @@ MP4::Tag::Tag(TagLib::File *file, MP4::Atoms *atoms) :
+       parseIntPair(atom);
+     }
+     else if(atom->name == "cpil" || atom->name == "pgap" || atom->name == "pcst" ||
+-            atom->name == "hdvd") {
++            atom->name == "hdvd" || atom->name == "shwm") {
+       parseBool(atom);
+     }
+-    else if(atom->name == "tmpo") {
++    else if(atom->name == "tmpo" || atom->name == "\251mvi" || atom->name == "\251mvc") {
+       parseInt(atom);
+     }
+     else if(atom->name == "tvsn" || atom->name == "tves" || atom->name == "cnID" ||
+@@ -472,10 +472,11 @@ MP4::Tag::save()
+     else if(name == "disk") {
+       data.append(renderIntPairNoTrailing(name.data(String::Latin1), it->second));
+     }
+-    else if(name == "cpil" || name == "pgap" || name == "pcst" || name == "hdvd") {
++    else if(name == "cpil" || name == "pgap" || name == "pcst" || name == "hdvd" ||
++            name == "shwm") {
+       data.append(renderBool(name.data(String::Latin1), it->second));
+     }
+-    else if(name == "tmpo") {
++    else if(name == "tmpo" || name == "\251mvi" || name == "\251mvc") {
+       data.append(renderInt(name.data(String::Latin1), it->second));
+     }
+     else if(name == "tvsn" || name == "tves" || name == "cnID" ||
+@@ -844,6 +845,11 @@ namespace
+     { "sonm", "TITLESORT" },
+     { "soco", "COMPOSERSORT" },
+     { "sosn", "SHOWSORT" },
++    { "shwm", "SHOWWORKMOVEMENT" },
++    { "\251wrk", "WORK" },
++    { "\251mvn", "MOVEMENTNAME" },
++    { "\251mvi", "MOVEMENTNUMBER" },
++    { "\251mvc", "MOVEMENTCOUNT" },
+     { "----:com.apple.iTunes:MusicBrainz Track Id", "MUSICBRAINZ_TRACKID" },
+     { "----:com.apple.iTunes:MusicBrainz Artist Id", "MUSICBRAINZ_ARTISTID" },
+     { "----:com.apple.iTunes:MusicBrainz Album Id", "MUSICBRAINZ_ALBUMID" },
+@@ -897,10 +903,10 @@ PropertyMap MP4::Tag::properties() const
+         }
+         props[key] = value;
+       }
+-      else if(key == "BPM") {
++      else if(key == "BPM" || key == "MOVEMENTNUMBER" || key == "MOVEMENTCOUNT") {
+         props[key] = String::number(it->second.toInt());
+       }
+-      else if(key == "COMPILATION") {
++      else if(key == "COMPILATION" || key == "SHOWWORKMOVEMENT") {
+         props[key] = String::number(it->second.toBool());
+       }
+       else {
+@@ -952,11 +958,11 @@ PropertyMap MP4::Tag::setProperties(const PropertyMap &props)
+           d->items[name] = MP4::Item(first, second);
+         }
+       }
+-      else if(it->first == "BPM" && !it->second.isEmpty()) {
++      else if((it->first == "BPM" || it->first == "MOVEMENTNUMBER" || it->first == "MOVEMENTCOUNT") && !it->second.isEmpty()) {
+         int value = it->second.front().toInt();
+         d->items[name] = MP4::Item(value);
+       }
+-      else if(it->first == "COMPILATION" && !it->second.isEmpty()) {
++      else if((it->first == "COMPILATION" || it->first == "SHOWWORKMOVEMENT") && !it->second.isEmpty()) {
+         bool value = (it->second.front().toInt() != 0);
+         d->items[name] = MP4::Item(value);
+       }
+diff --git a/taglib/mp4/mp4tag.h b/taglib/mp4/mp4tag.h
+index d477a86..bca3021 100644
+--- a/taglib/mp4/mp4tag.h
++++ b/taglib/mp4/mp4tag.h
+@@ -35,6 +35,8 @@
+ #include "mp4atom.h"
+ #include "mp4item.h"
+ 
++#define TAGLIB_WITH_MP4_SHWM 1
++
+ namespace TagLib {
+ 
+   namespace MP4 {
+diff --git a/taglib/mpeg/id3v2/id3v2frame.cpp b/taglib/mpeg/id3v2/id3v2frame.cpp
+index 1f896fa..ec3b931 100644
+--- a/taglib/mpeg/id3v2/id3v2frame.cpp
++++ b/taglib/mpeg/id3v2/id3v2frame.cpp
+@@ -111,8 +111,8 @@ Frame *Frame::createTextualFrame(const String &key, const StringList &values) //
+   // check if the key is contained in the key<=>frameID mapping
+   ByteVector frameID = keyToFrameID(key);
+   if(!frameID.isEmpty()) {
+-    // Apple proprietary WFED (Podcast URL) is in fact a text frame.
+-    if(frameID[0] == 'T' || frameID == "WFED"){ // text frame
++    // Apple proprietary WFED (Podcast URL), MVNM (Movement Name), MVIN (Movement Number) are in fact text frames.
++    if(frameID[0] == 'T' || frameID == "WFED" || frameID == "MVNM" || frameID == "MVIN"){ // text frame
+       TextIdentificationFrame *frame = new TextIdentificationFrame(frameID, String::UTF8);
+       frame->setText(values);
+       return frame;
+@@ -392,6 +392,8 @@ namespace
+     { "TDES", "PODCASTDESC" },
+     { "TGID", "PODCASTID" },
+     { "WFED", "PODCASTURL" },
++    { "MVNM", "MOVEMENTNAME" },
++    { "MVIN", "MOVEMENTNUMBER" },
+   };
+   const size_t frameTranslationSize = sizeof(frameTranslation) / sizeof(frameTranslation[0]);
+ 
+@@ -474,8 +476,8 @@ PropertyMap Frame::asProperties() const
+   // workaround until this function is virtual
+   if(id == "TXXX")
+     return dynamic_cast< const UserTextIdentificationFrame* >(this)->asProperties();
+-  // Apple proprietary WFED (Podcast URL) is in fact a text frame.
+-  else if(id[0] == 'T' || id == "WFED")
++  // Apple proprietary WFED (Podcast URL), MVNM (Movement Name), MVIN (Movement Number) are in fact text frames.
++  else if(id[0] == 'T' || id == "WFED" || id == "MVNM" || id == "MVIN")
+     return dynamic_cast< const TextIdentificationFrame* >(this)->asProperties();
+   else if(id == "WXXX")
+     return dynamic_cast< const UserUrlLinkFrame* >(this)->asProperties();
+diff --git a/taglib/mpeg/id3v2/id3v2framefactory.cpp b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+index 0fbb87d..759a9b7 100644
+--- a/taglib/mpeg/id3v2/id3v2framefactory.cpp
++++ b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+@@ -198,8 +198,8 @@ Frame *FrameFactory::createFrame(const ByteVector &origData, Header *tagHeader)
+ 
+   // Text Identification (frames 4.2)
+ 
+-  // Apple proprietary WFED (Podcast URL) is in fact a text frame.
+-  if(frameID.startsWith("T") || frameID == "WFED") {
++  // Apple proprietary WFED (Podcast URL), MVNM (Movement Name), MVIN (Movement Number) are in fact text frames.
++  if(frameID.startsWith("T") || frameID == "WFED" || frameID == "MVNM" || frameID == "MVIN") {
+ 
+     TextIdentificationFrame *f = frameID != "TXXX"
+       ? new TextIdentificationFrame(data, header)
+@@ -456,6 +456,8 @@ namespace
+     { "TDS", "TDES" },
+     { "TID", "TGID" },
+     { "WFD", "WFED" },
++    { "MVN", "MVNM" },
++    { "MVI", "MVIN" },
+   };
+   const size_t frameConversion2Size = sizeof(frameConversion2) / sizeof(frameConversion2[0]);
+ 
+EOF
+
 test -f mp4v2_win32.patch ||
 cat >mp4v2_win32.patch <<"EOF"
 diff -ruN mp4v2-2.0.0.orig/GNUmakefile.am mp4v2-2.0.0/GNUmakefile.am
@@ -1822,11 +1988,38 @@ index e447a0c..b8f25ee 100644
  }
  
 EOF
+
+test -f ffmpeg_mingw.patch ||
+cat >ffmpeg_mingw.patch <<"EOF"
+From a64839189622f2a4cc3c62168ae5037b6aab6992 Mon Sep 17 00:00:00 2001
+From: Tobias Rapp <t.rapp@noa-archive.com>
+Date: Mon, 29 Aug 2016 15:25:58 +0200
+Subject: cmdutils: fix implicit declaration of SetDllDirectory function
+
+Signed-off-by: Tobias Rapp <t.rapp@noa-archive.com>
+Signed-off-by: James Almer <jamrial@gmail.com>
+
+diff --git a/cmdutils.c b/cmdutils.c
+index 6960f8c..44f44cd 100644
+--- a/cmdutils.c
++++ b/cmdutils.c
+@@ -61,6 +61,9 @@
+ #include <sys/time.h>
+ #include <sys/resource.h>
+ #endif
++#ifdef _WIN32
++#include <windows.h>
++#endif
+ 
+ static int init_report(const char *env);
+EOF
+
 cd ..
 
 
 # Extract and patch sources
 
+if test -n "$ZLIB_ROOT_PATH"; then
 echo "### Extracting zlib"
 
 if ! test -d zlib-${zlib_version}; then
@@ -1838,6 +2031,7 @@ echo Can be ignored: Cannot create symlink to debian.series
 for f in $(cat debian/patches/debian.series); do patch -p1 <debian/patches/$f; done
 cd ..
 fi
+fi
 
 echo "### Extracting libogg"
 
@@ -1918,6 +2112,9 @@ fi
 if test "${taglib_version}" = "1.9.1"; then
   patch -p1 <../source/taglib_bvreplace.patch
 fi
+if test "${taglib_version}" = "1.11.1"; then
+  patch -p1 <../source/taglib_mp4shwm.patch
+fi
 cd ..
 fi
 
@@ -1928,6 +2125,9 @@ unxz -c source/ffmpeg_${ffmpeg_version}.orig.tar.xz | tar x || true
 cd ffmpeg-${ffmpeg_version}/
 unxz -c ../source/ffmpeg_${ffmpeg_version}-${ffmpeg_patchlevel}.debian.tar.xz | tar x
 for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+if test $ffmpeg_version = "3.1.3"; then
+  patch -p1 <../source/ffmpeg_mingw.patch
+fi
 cd ..
 else
 if test "${libav_version%.*}" = "0.8"; then
@@ -1994,6 +2194,13 @@ fi
 
 test -d bin || mkdir bin
 
+for d in /usr/share/xml/docbook/stylesheet/nwalsh /usr/share/xml/docbook/xsl-stylesheets-*; do
+  if test -e $d/html/docbook.xsl; then
+    _docbook_xsl_dir=$d
+    break
+  fi
+done
+
 if test "$compiler" = "cross-android"; then
 
 echo "### Building taglib"
@@ -2024,7 +2231,7 @@ _android_abi=$_android_abi
 _android_toolchain_prefix=$_android_toolchain_prefix
 _android_qt_root=$_android_qt_root
 _buildprefix=\$(cd ..; pwd)/buildroot/usr/local
-cmake -DJAVA_HOME=\$_java_root -DQT_ANDROID_SDK_ROOT=\$_android_sdk_root -DANDROID_NDK=\$_android_ndk_root -DQT_ANDROID_ANT=/usr/bin/ant -DAPK_ALL_TARGET=OFF -DANDROID_ABI=\$_android_abi -DANDROID_TOOLCHAIN_PREFIX=\$_android_toolchain_prefix -DCMAKE_TOOLCHAIN_FILE=../../kid3/android/qt-android-cmake/toolchain/android.toolchain.cmake -DQT_QMAKE_EXECUTABLE=\$_android_qt_root/bin/qmake -DCMAKE_BUILD_TYPE=Release -DDOCBOOK_XSL_DIR=/usr/share/xml/docbook/stylesheet/nwalsh -DPYTHON_EXECUTABLE=/usr/bin/python -DXSLTPROC=/usr/bin/xsltproc -DGZIP_EXECUTABLE=/bin/gzip -DTAGLIBCONFIG_EXECUTABLE=\$_buildprefix/bin/taglib-config ../../kid3
+cmake -DJAVA_HOME=\$_java_root -DQT_ANDROID_SDK_ROOT=\$_android_sdk_root -DANDROID_NDK=\$_android_ndk_root -DQT_ANDROID_ANT=/usr/bin/ant -DAPK_ALL_TARGET=OFF -DANDROID_ABI=\$_android_abi -DANDROID_TOOLCHAIN_PREFIX=\$_android_toolchain_prefix -DCMAKE_TOOLCHAIN_FILE=../../kid3/android/qt-android-cmake/toolchain/android.toolchain.cmake -DQT_QMAKE_EXECUTABLE=\$_android_qt_root/bin/qmake -DCMAKE_BUILD_TYPE=Release -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} -DPYTHON_EXECUTABLE=/usr/bin/python -DXSLTPROC=/usr/bin/xsltproc -DGZIP_EXECUTABLE=/bin/gzip -DTAGLIBCONFIG_EXECUTABLE=\$_buildprefix/bin/taglib-config ../../kid3
 EOF
   chmod +x kid3/build.sh
 fi
@@ -2104,11 +2311,11 @@ if test "$1" = "clean"; then
            id3lib-${id3lib_version} taglib-${taglib_version} \
            ${ffmpeg_dir} chromaprint-${chromaprint_version} \
            mp4v2-${mp4v2_version}; do
-    rm -rf $d/inst
+    test -d $d/inst && rm -rf $d/inst
   done
 fi
 
-if test ! -d zlib-${zlib_version}/inst; then
+if test -n "$ZLIB_ROOT_PATH" && test ! -d zlib-${zlib_version}/inst; then
 echo "### Building zlib"
 
 cd zlib-${zlib_version}/
@@ -2205,7 +2412,7 @@ if test ! -d taglib-${taglib_version}/inst; then
 echo "### Building taglib"
 
 cd taglib-${taglib_version}/
-test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib $taglib_static_option -DZLIB_ROOT=../zlib-$zlib_version/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+test -f Makefile || eval cmake -DWITH_ASF=ON -DWITH_MP4=ON -DINCLUDE_DIRECTORIES=/usr/local/include -DLINK_DIRECTORIES=/usr/local/lib $taglib_static_option $TAGLIB_ZLIB_ROOT_OPTION $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
 make VERBOSE=1
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
@@ -2417,6 +2624,9 @@ AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS $AV_BUILD_OPTION"
 	--enable-decoder=pcm_u24be \
 	--enable-decoder=pcm_u24le \
 	--enable-decoder=rawvideo \
+	--disable-videotoolbox \
+	--disable-vaapi \
+	--disable-vdpau \
 	--disable-hwaccel=h264_dxva2 \
 	--disable-hwaccel=mpeg2_dxva2 $AV_CONFIGURE_OPTIONS
 make V=1
@@ -2433,7 +2643,7 @@ echo "### Building chromaprint"
 
 # The zlib library path was added for MinGW-builds GCC 4.7.2.
 cd chromaprint-${chromaprint_version}/
-test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-$zlib_version/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/$ffmpeg_dir/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
+test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF $CHROMAPRINT_ZLIB_OPTION -DFFMPEG_ROOT=$thisdir/$ffmpeg_dir/inst/usr/local $CMAKE_BUILD_OPTION $CMAKE_OPTIONS
 make VERBOSE=1
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
@@ -2471,35 +2681,45 @@ if test $kernel = "Linux"; then
     mkdir kid3
     if test "$compiler" = "cross-mingw"; then
       cat >kid3/build.sh <<EOF
-cmake $CMAKE_BUILD_OPTION -DCMAKE_TOOLCHAIN_FILE=$thisdir/source/mingw.cmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DDOCBOOK_XSL_DIR=/usr/share/xml/docbook/stylesheet/nwalsh ../../kid3
+cmake $CMAKE_BUILD_OPTION -DCMAKE_TOOLCHAIN_FILE=$thisdir/source/mingw.cmake -DCMAKE_INSTALL_PREFIX= -DWITH_FFMPEG=ON -DWITH_MP4V2=ON -DCMAKE_CXX_FLAGS="-g -O2 -DMP4V2_USE_STATIC_LIB" -DDOCBOOK_XSL_DIR=${_docbook_xsl_dir} ../../kid3
 EOF
-      cat >kid3/make_package.sh <<"EOF"
-#!/bin/sh
-VERSION=$(grep VERSION config.h | cut -d'"' -f2)
-INSTDIR=kid3-$VERSION-win32
-QT_PREFIX=$(sed "s/set(QT_PREFIX \(.*\))/\1/;q" ../source/mingw.cmake)
-QT_BIN_DIR=${QT_PREFIX}/bin
-QT_TRANSLATIONS_DIR=${QT_PREFIX}/translations
+      cat >kid3/make_package.sh <<EOF
+#!/bin/bash
+VERSION=\$(grep VERSION config.h | cut -d'"' -f2)
+INSTDIR=kid3-\$VERSION-win32
+QT_PREFIX=\$(sed "s/set(QT_PREFIX \(.*\))/\1/;q" ../source/mingw.cmake)
+QT_BIN_DIR=\${QT_PREFIX}/bin
+QT_TRANSLATIONS_DIR=\${QT_PREFIX}/translations
 
-test -d $INSTDIR && rm -rf $INSTDIR
-mkdir -p $INSTDIR
-make install/strip DESTDIR=$(pwd)/$INSTDIR
+test -d \$INSTDIR && rm -rf \$INSTDIR
+mkdir -p \$INSTDIR
+make install/strip DESTDIR=\$(pwd)/\$INSTDIR
 echo "### Ignore make error"
 
-cp -f po/*.qm doc/*/kid3*.html $INSTDIR
+_plugin_qt_version=\$(grep "Created by.*Qt" src/plugins/musicbrainzimport/moc_musicbrainzimportplugin.cpp)
+_plugin_qt_version=\${_plugin_qt_version##* \(Qt }
+_plugin_qt_version=\${_plugin_qt_version%%\)*}
+_plugin_qt_version_nr=\${_plugin_qt_version//./}
+if test \$_plugin_qt_version_nr -gt ${qt_version//./}; then
+  echo "Plugin Qt version \$_plugin_qt_version is larger than Qt version $qt_version."
+  echo "Loading plugins will fail!"
+  exit 1
+fi
+
+cp -f po/*.qm doc/*/kid3*.html \$INSTDIR
 
 for f in Qt5Core.dll Qt5Network.dll Qt5Gui.dll Qt5Xml.dll Qt5Widgets.dll Qt5Multimedia.dll Qt5Qml.dll Qt5Quick.dll libgcc_s_dw2-1.dll libstdc++-6.dll libwinpthread-1.dll; do
-  cp $QT_BIN_DIR/$f $INSTDIR
+  cp \$QT_BIN_DIR/\$f \$INSTDIR
 done
 
 for f in po/*.qm; do
-  l=${f#*_};
-  l=${l%.qm};
-  test -f $QT_TRANSLATIONS_DIR/qtbase_$l.qm && cp $QT_TRANSLATIONS_DIR/qtbase_$l.qm $INSTDIR
+  l=\${f#*_};
+  l=\${l%.qm};
+  test -f \$QT_TRANSLATIONS_DIR/qtbase_\$l.qm && cp \$QT_TRANSLATIONS_DIR/qtbase_\$l.qm \$INSTDIR
 done
 
-rm -f $INSTDIR.zip
-7z a $INSTDIR.zip $INSTDIR
+rm -f \$INSTDIR.zip
+7z a \$INSTDIR.zip \$INSTDIR
 EOF
       chmod +x kid3/make_package.sh
     else
@@ -2508,7 +2728,9 @@ EOF
       cat >kid3/build.sh <<EOF
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
-cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QT5=ON -DWITH_QML=OFF -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DBUILD_SHARED_LIBS=OFF -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
+# For a LINUX_SELF_CONTAINED build, change BUILD_SHARED_LIBS to ON and add
+# -G Ninja -DCMAKE_CXX_COMPILER=g++-4.7 -DCMAKE_C_COMPILER=gcc-4.7 -DQT_QMAKE_EXECUTABLE=/opt/Qt5.6.2/5.6/gcc_64/bin/qmake -DLINUX_SELF_CONTAINED=ON
+cmake -DBUILD_SHARED_LIBS=OFF -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QT5=ON -DWITH_QML=OFF -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON $CMAKE_BUILD_OPTION -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. -DWITH_LIBDIR=. -DWITH_PLUGINSDIR=./plugins ../../kid3
 EOF
     fi
     chmod +x kid3/build.sh
@@ -2520,7 +2742,9 @@ else
   tar_cmd="tar xmzf"
 fi
 
-${tar_cmd} bin/zlib-${zlib_version}.tgz -C $BUILDROOT
+if test -n "$ZLIB_ROOT_PATH"; then
+  ${tar_cmd} bin/zlib-${zlib_version}.tgz -C $BUILDROOT
+fi
 ${tar_cmd} bin/libogg-${libogg_version}.tgz -C $BUILDROOT
 ${tar_cmd} bin/libvorbis-${libvorbis_version}.tgz -C $BUILDROOT
 ${tar_cmd} bin/flac-${libflac_version}.tgz -C $BUILDROOT
