@@ -34,6 +34,9 @@ namespace {
 /** Default value for comment name */
 const char* const defaultCommentName = "COMMENT";
 
+/** Default value for RIFF track name */
+const char* const defaultRiffTrackName = "IPRT";
+
 }
 
 int TagConfig::s_index = -1;
@@ -44,6 +47,7 @@ int TagConfig::s_index = -1;
 TagConfig::TagConfig() :
   StoredConfig<TagConfig>(QLatin1String("Tags")),
   m_commentName(QString::fromLatin1(defaultCommentName)),
+  m_riffTrackName(QString::fromLatin1(defaultRiffTrackName)),
   m_pictureNameItem(VP_METADATA_BLOCK_PICTURE),
   m_id3v2Version(ID3v2_3_0),
   m_textEncodingV1(QLatin1String("ISO-8859-1")),
@@ -56,9 +60,11 @@ TagConfig::TagConfig() :
   m_onlyCustomGenres(false),
   m_markTruncations(true),
   m_enableTotalNumberOfTracks(false),
-  m_genreNotNumeric(true)
+  m_genreNotNumeric(true),
+  m_lowercaseId3RiffChunk(false)
 {
-  m_disabledPlugins << QLatin1String("Id3libMetadata");
+  m_disabledPlugins << QLatin1String("Id3libMetadata")
+                    << QLatin1String("Mp4v2Metadata");
 }
 
 /**
@@ -79,8 +85,10 @@ void TagConfig::writeToConfig(ISettings* config) const
   config->setValue(QLatin1String("MaximumPictureSize"), QVariant(m_maximumPictureSize));
   config->setValue(QLatin1String("EnableTotalNumberOfTracks"), QVariant(m_enableTotalNumberOfTracks));
   config->setValue(QLatin1String("GenreNotNumeric"), QVariant(m_genreNotNumeric));
+  config->setValue(QLatin1String("LowercaseId3RiffChunk"), QVariant(m_lowercaseId3RiffChunk));
   config->setValue(QLatin1String("CommentName"), QVariant(m_commentName));
   config->setValue(QLatin1String("PictureNameItem"), QVariant(m_pictureNameItem));
+  config->setValue(QLatin1String("RiffTrackName"), QVariant(m_riffTrackName));
   config->setValue(QLatin1String("CustomGenres"), QVariant(m_customGenres));
   config->setValue(QLatin1String("ID3v2Version"), QVariant(m_id3v2Version));
   config->setValue(QLatin1String("TextEncodingV1"), QVariant(m_textEncodingV1));
@@ -113,8 +121,10 @@ void TagConfig::readFromConfig(ISettings* config)
   m_maximumPictureSize = config->value(QLatin1String("MaximumPictureSize"), m_maximumPictureSize).toInt();
   m_enableTotalNumberOfTracks = config->value(QLatin1String("EnableTotalNumberOfTracks"), m_enableTotalNumberOfTracks).toBool();
   m_genreNotNumeric = config->value(QLatin1String("GenreNotNumeric"), m_genreNotNumeric).toBool();
+  m_lowercaseId3RiffChunk = config->value(QLatin1String("LowercaseId3RiffChunk"), m_lowercaseId3RiffChunk).toBool();
   m_commentName = config->value(QLatin1String("CommentName"), QString::fromLatin1(defaultCommentName)).toString();
   m_pictureNameItem = config->value(QLatin1String("PictureNameItem"), VP_METADATA_BLOCK_PICTURE).toInt();
+  m_riffTrackName = config->value(QLatin1String("RiffTrackName"), QString::fromLatin1(defaultRiffTrackName)).toString();
   m_customGenres = config->value(QLatin1String("CustomGenres"),
                                  m_customGenres).toStringList();
   m_id3v2Version = config->value(QLatin1String("ID3v2Version"), ID3v2_3_0).toInt();
@@ -230,6 +240,15 @@ void TagConfig::setGenreNotNumeric(bool genreNotNumeric)
   }
 }
 
+/** Set true to use "id3 " instead of "ID3 " chunk names in WAV files */
+void TagConfig::setLowercaseId3RiffChunk(bool lowercaseId3RiffChunk)
+{
+  if (m_lowercaseId3RiffChunk != lowercaseId3RiffChunk) {
+    m_lowercaseId3RiffChunk = lowercaseId3RiffChunk;
+    emit lowercaseId3RiffChunkChanged(m_lowercaseId3RiffChunk);
+  }
+}
+
 /** Set field name used for Vorbis comment entries. */
 void TagConfig::setCommentName(const QString& commentName)
 {
@@ -248,6 +267,15 @@ void TagConfig::setPictureNameIndex(int pictureNameItem)
   }
 }
 
+/** Set field name used for RIFF track entries. */
+void TagConfig::setRiffTrackName(const QString& riffTrackName)
+{
+  if (m_riffTrackName != riffTrackName) {
+    m_riffTrackName = riffTrackName;
+    emit riffTrackNameChanged(m_riffTrackName);
+  }
+}
+
 /** Set custom genres for ID3v2.3. */
 void TagConfig::setCustomGenres(const QStringList& customGenres)
 {
@@ -412,3 +440,13 @@ QStringList TagConfig::getPictureNames()
   return QStringList() << QLatin1String("METADATA_BLOCK_PICTURE")
                        << QLatin1String("COVERART");
 }
+
+/**
+ * String list with suggested field names used for RIFF track entries.
+ */
+QStringList TagConfig::getRiffTrackNames()
+{
+  return QStringList() << QLatin1String("IPRT")
+                       << QLatin1String("ITRK")
+                       << QLatin1String("TRCK");
+}
