@@ -48,10 +48,14 @@ class KID3_CORE_EXPORT TagConfig : public StoredConfig<TagConfig> {
   Q_PROPERTY(bool enableTotalNumberOfTracks READ enableTotalNumberOfTracks WRITE setEnableTotalNumberOfTracks NOTIFY enableTotalNumberOfTracksChanged)
   /** true to write genres as text instead of numeric string */
   Q_PROPERTY(bool genreNotNumeric READ genreNotNumeric WRITE setGenreNotNumeric NOTIFY genreNotNumericChanged)
+  /** true to use "id3 " instead of "ID3 " chunk names in WAV files */
+  Q_PROPERTY(bool lowercaseId3RiffChunk READ lowercaseId3RiffChunk WRITE setLowercaseId3RiffChunk NOTIFY lowercaseId3RiffChunkChanged)
   /** field name used for Vorbis comment entries */
   Q_PROPERTY(QString commentName READ commentName WRITE setCommentName NOTIFY commentNameChanged)
   /** index of field name used for Vorbis picture entries */
   Q_PROPERTY(int pictureNameIndex READ pictureNameIndex WRITE setPictureNameIndex NOTIFY pictureNameIndexChanged)
+  /** field name used for RIFF track entries */
+  Q_PROPERTY(QString riffTrackName READ riffTrackName WRITE setRiffTrackName NOTIFY riffTrackNameChanged)
   /** custom genres for ID3v2.3 */
   Q_PROPERTY(QStringList customGenres READ customGenres WRITE setCustomGenres NOTIFY customGenresChanged)
   /** version used for new ID3v2 tags */
@@ -169,6 +173,12 @@ public:
   /** Set true to write genres as text instead of numeric string. */
   void setGenreNotNumeric(bool genreNotNumeric);
 
+  /** true to use "id3 " instead of "ID3 " chunk names in WAV files */
+  bool lowercaseId3RiffChunk() const { return m_lowercaseId3RiffChunk; }
+
+  /** Set true to use "id3 " instead of "ID3 " chunk names in WAV files */
+  void setLowercaseId3RiffChunk(bool lowercaseId3RiffChunk);
+
   /** field name used for Vorbis comment entries */
   QString commentName() const { return m_commentName; }
 
@@ -181,6 +191,12 @@ public:
   /** Set index of field name used for Vorbis picture entries. */
   void setPictureNameIndex(int pictureNameIndex);
 
+  /** field name used for RIFF track entries */
+  QString riffTrackName() const { return m_riffTrackName; }
+
+  /** Set field name used for RIFF track entries. */
+  void setRiffTrackName(const QString& riffTrackName);
+
   /** custom genres for ID3v2.3 */
   QStringList customGenres() const { return m_customGenres; }
 
@@ -288,6 +304,11 @@ public:
    */
   Q_INVOKABLE static QStringList getPictureNames();
 
+  /**
+   * String list with suggested field names used for RIFF track entries.
+   */
+  Q_INVOKABLE static QStringList getRiffTrackNames();
+
   /**
    * Set default plugin order.
    */
@@ -312,12 +333,18 @@ signals:
   /** Emitted when @a genreNotNumeric changed. */
   void genreNotNumericChanged(bool genreNotNumeric);
 
+  /** Emitted when @a lowercaseId3RiffChunk changed. */
+  void lowercaseId3RiffChunkChanged(bool lowercaseId3RiffChunk);
+
   /** Emitted when @a commentName changed. */
   void commentNameChanged(const QString& commentName);
 
   /** Emitted when @a pictureNameIndex changed. */
   void pictureNameIndexChanged(int pictureNameIndex);
 
+  /** Emitted when @a riffTrackName changed. */
+  void riffTrackNameChanged(const QString& riffTrackName);
+
   /** Emitted when @a customGenres changed. */
   void customGenresChanged(const QStringList& customGenres);
 
@@ -355,6 +382,7 @@ private:
   friend TagConfig& StoredConfig<TagConfig>::instance();
 
   QString m_commentName;
+  QString m_riffTrackName;
   int m_pictureNameItem;
   QStringList m_customGenres;
   int m_id3v2Version;
@@ -373,6 +401,7 @@ private:
   bool m_markTruncations;
   bool m_enableTotalNumberOfTracks;
   bool m_genreNotNumeric;
+  bool m_lowercaseId3RiffChunk;
 
   /** Index in configuration storage */
   static int s_index;
