@@ -101,13 +101,36 @@ void HttpClient::networkReplyFinished()
     QByteArray data(reply->readAll());
     m_rcvBodyType = reply->header(QNetworkRequest::ContentTypeHeader).toString();
     m_rcvBodyLen = reply->header(QNetworkRequest::ContentLengthHeader).toUInt();
-    emit bytesReceived(data);
     QString msg(tr("Ready."));
     if (reply->error() != QNetworkReply::NoError) {
       msg = tr("Error");
       msg += QLatin1String(": ");
       msg += reply->errorString();
+    } else {
+      QVariant redirect =
+          reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
+      if (!redirect.isNull()) {
+        QUrl redirectUrl = redirect.toUrl();
+        if (redirectUrl.isRelative()) {
+          redirectUrl = reply->url().resolved(redirectUrl);
+        }
+        if (redirectUrl.isValid()) {
+          reply->deleteLater();
+
+          QNetworkRequest request(redirectUrl);
+          reply = m_netMgr->get(request);
+          m_reply = reply;
+          connect(reply, SIGNAL(finished()),
+                  this, SLOT(networkReplyFinished()));
+          connect(reply, SIGNAL(downloadProgress(qint64,qint64)),
+                  this, SLOT(networkReplyProgress(qint64,qint64)));
+          connect(reply, SIGNAL(error(QNetworkReply::NetworkError)),
+                  this, SLOT(networkReplyError(QNetworkReply::NetworkError)));
+          return;
+        }
+      }
     }
+    emit bytesReceived(data);
     emitProgress(msg, data.size(), data.size());
     reply->deleteLater();
   }
@@ -208,10 +231,11 @@ void HttpClient::sendRequest(const QUrl& url, const RawHeaderMap& headers)
  *
  * @param server host name
  * @param path   path of the URL
+ * @param scheme scheme, default is "http"
  * @param headers optional raw headers to send
  */
 void HttpClient::sendRequest(const QString& server, const QString& path,
-                             const RawHeaderMap& headers)
+                             const QString& scheme, const RawHeaderMap& headers)
 {
   QString host(server);
   if (host.endsWith(QLatin1String(":80"))) {
@@ -219,9 +243,9 @@ void HttpClient::sendRequest(const QString& server, const QString& path,
   }
   QUrl url;
 #if QT_VERSION >= 0x050000
-  url.setUrl(QLatin1String("http://") + host + path);
+  url.setUrl(scheme + QLatin1String("://") + host + path);
 #else
-  url.setEncodedUrl((QLatin1String("http://") + host + path).toAscii());
+  url.setEncodedUrl((scheme + QLatin1String("://") + host + path).toAscii());
 #endif
   sendRequest(url, headers);
 }
