@@ -284,7 +284,7 @@ QVariant FileProxyModel::data(const QModelIndex& index, int role) const
       TaggedFile* taggedFile = m_taggedFiles.value(index, 0);
       return taggedFile &&
           ((TagConfig::instance().markTruncations() &&
-            taggedFile->getTruncationFlags() != 0) ||
+            taggedFile->getTruncationFlags(Frame::Tag_Id3v1) != 0) ||
            taggedFile->isMarked());
     } else if (role == IsDirRole && index.column() == 0) {
       return isDir(index);
@@ -702,8 +702,8 @@ TaggedFile* FileProxyModel::readWithId3V24IfId3V24(TaggedFile* taggedFile)
        (TaggedFile::TF_ID3v23 | TaggedFile::TF_ID3v24)) ==
         TaggedFile::TF_ID3v23 &&
       !taggedFile->isChanged() &&
-      taggedFile->isTagInformationRead() && taggedFile->hasTagV2()) {
-    QString id3v2Version = taggedFile->getTagFormatV2();
+      taggedFile->isTagInformationRead() && taggedFile->hasTag(Frame::Tag_Id3v2)) {
+    QString id3v2Version = taggedFile->getTagFormat(Frame::Tag_Id3v2);
     if (id3v2Version.isNull() || id3v2Version == QLatin1String("ID3v2.2.0")) {
       taggedFile = readWithId3V24(taggedFile);
     }
@@ -811,3 +811,51 @@ void FileProxyModel::notifyModelDataChanged(const QModelIndex& index)
 {
   emit dataChanged(index, index);
 }
+
+/**
+ * Create name-file pattern pairs for all supported types.
+ * The order is the same as in createFilterString().
+ *
+ * @return pairs containing name, pattern, e.g. ("MP3", "*.mp3"), ...,
+ * ("All Files", "*").
+ */
+QList<QPair<QString, QString> > FileProxyModel::createNameFilters()
+{
+  QStringList extensions;
+  foreach (ITaggedFileFactory* factory, taggedFileFactories()) {
+    foreach (const QString& key, factory->taggedFileKeys()) {
+      extensions.append(factory->supportedFileExtensions(key));
+    }
+  }
+  // remove duplicates
+  extensions.sort();
+  QString lastExt(QLatin1String(""));
+  for (QStringList::iterator it = extensions.begin();
+       it != extensions.end();) {
+    if (*it == lastExt) {
+      it = extensions.erase(it);
+    } else {
+      lastExt = *it;
+      ++it;
+    }
+  }
+
+  QString allPatterns;
+  QList<QPair<QString, QString> > nameFilters;
+  for (QStringList::const_iterator it = extensions.begin();
+       it != extensions.end();
+       ++it) {
+    QString text = (*it).mid(1).toUpper();
+    QString pattern = QLatin1Char('*') + *it;
+    if (!allPatterns.isEmpty()) {
+      allPatterns += QLatin1Char(' ');
+    }
+    allPatterns += pattern;
+    nameFilters.append(qMakePair(text, pattern));
+  }
+  if (!allPatterns.isEmpty()) {
+    nameFilters.prepend(qMakePair(tr("All Supported Files"), allPatterns));
+  }
+  nameFilters.append(qMakePair(tr("All Files"), QString(QLatin1Char('*'))));
+  return nameFilters;
+}
