@@ -71,10 +71,12 @@ ConfigDialogPages::ConfigDialogPages(IPlatformTools* platformTools,
   m_totalNumTracksCheckBox(0), m_commentNameComboBox(0),
   m_pictureNameComboBox(0), m_markOversizedPicturesCheckBox(0),
   m_maximumPictureSizeSpinBox(0), m_genreNotNumericCheckBox(0),
+  m_lowercaseId3ChunkCheckBox(0),
   m_textEncodingComboBox(0), m_id3v2VersionComboBox(0),
   m_trackNumberDigitsSpinBox(0), m_fnFormatBox(0), m_tagFormatBox(0),
   m_onlyCustomGenresCheckBox(0), m_genresEditModel(0),
-  m_quickAccessTagsModel(0), m_playOnDoubleClickCheckBox(0),
+  m_quickAccessTagsModel(0), m_trackNameComboBox(0),
+  m_playOnDoubleClickCheckBox(0),
   m_commandsTable(0), m_commandsTableModel(0), m_browserLineEdit(0),
   m_proxyCheckBox(0), m_proxyLineEdit(0), m_proxyAuthenticationCheckBox(0),
   m_proxyUserNameLineEdit(0), m_proxyPasswordLineEdit(0),
@@ -125,14 +127,16 @@ QWidget* ConfigDialogPages::createTagsPage()
   m_trackNumberDigitsSpinBox = new QSpinBox(v2GroupBox);
   m_trackNumberDigitsSpinBox->setMaximum(5);
   m_genreNotNumericCheckBox = new QCheckBox(tr("&Genre as text instead of numeric string"), v2GroupBox);
+  m_lowercaseId3ChunkCheckBox = new QCheckBox(tr("&WAV files with lowercase id3 chunk"), v2GroupBox);
   QLabel* textEncodingLabel = new QLabel(tr("Text &encoding:"), v2GroupBox);
   m_textEncodingComboBox = new QComboBox(v2GroupBox);
   m_textEncodingComboBox->addItems(TagConfig::getTextEncodingNames());
   m_textEncodingComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   textEncodingLabel->setBuddy(m_textEncodingComboBox);
   v2GroupBoxLayout->addWidget(m_genreNotNumericCheckBox, 1, 0, 1, 2);
-  v2GroupBoxLayout->addWidget(textEncodingLabel, 2, 0);
-  v2GroupBoxLayout->addWidget(m_textEncodingComboBox, 2, 1);
+  v2GroupBoxLayout->addWidget(m_lowercaseId3ChunkCheckBox, 2, 0, 1, 2);
+  v2GroupBoxLayout->addWidget(textEncodingLabel, 3, 0);
+  v2GroupBoxLayout->addWidget(m_textEncodingComboBox, 3, 1);
   const TagConfig& tagCfg = TagConfig::instance();
   if (!(tagCfg.taggedFileFeatures() &
         (TaggedFile::TF_ID3v22 | TaggedFile::TF_ID3v23 | TaggedFile::TF_ID3v24))) {
@@ -148,15 +152,15 @@ QWidget* ConfigDialogPages::createTagsPage()
     m_id3v2VersionComboBox->addItem(tr("ID3v2.4.0"), TagConfig::ID3v2_4_0);
   m_id3v2VersionComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
   id3v2VersionLabel->setBuddy(m_id3v2VersionComboBox);
-  v2GroupBoxLayout->addWidget(id3v2VersionLabel, 3, 0);
-  v2GroupBoxLayout->addWidget(m_id3v2VersionComboBox, 3, 1);
+  v2GroupBoxLayout->addWidget(id3v2VersionLabel, 4, 0);
+  v2GroupBoxLayout->addWidget(m_id3v2VersionComboBox, 4, 1);
   if (m_id3v2VersionComboBox->count() < 2) {
     id3v2VersionLabel->hide();
     m_id3v2VersionComboBox->hide();
   }
   trackNumberDigitsLabel->setBuddy(m_trackNumberDigitsSpinBox);
-  v2GroupBoxLayout->addWidget(trackNumberDigitsLabel, 4, 0);
-  v2GroupBoxLayout->addWidget(m_trackNumberDigitsSpinBox, 4, 1);
+  v2GroupBoxLayout->addWidget(trackNumberDigitsLabel, 5, 0);
+  v2GroupBoxLayout->addWidget(m_trackNumberDigitsSpinBox, 5, 1);
   tag2LeftLayout->addWidget(v2GroupBox);
   QGroupBox* vorbisGroupBox = new QGroupBox(tr("Ogg/Vorbis"), tag2Page);
   QLabel* commentNameLabel = new QLabel(tr("Co&mment field name:"), vorbisGroupBox);
@@ -222,6 +226,22 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag2RightLayout->addWidget(quickAccessTagsGroupBox);
   tag2Layout->addLayout(tag2RightLayout);
 
+  QWidget* tag3Page = new QWidget;
+  QVBoxLayout* tag3Layout = new QVBoxLayout(tag3Page);
+  QGroupBox* riffGroupBox = new QGroupBox(tr("RIFF INFO"), tag3Page);
+  QLabel* trackNameLabel = new QLabel(tr("Track nu&mber field name:"), riffGroupBox);
+  m_trackNameComboBox = new QComboBox(riffGroupBox);
+  m_trackNameComboBox->setEditable(true);
+  m_trackNameComboBox->addItems(TagConfig::getRiffTrackNames());
+  m_trackNameComboBox->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
+  trackNameLabel->setBuddy(m_trackNameComboBox);
+  QGridLayout* riffGroupBoxLayout = new QGridLayout(riffGroupBox);
+  riffGroupBoxLayout->addWidget(trackNameLabel, 0, 0);
+  riffGroupBoxLayout->addWidget(m_trackNameComboBox, 0, 1);
+  riffGroupBox->setLayout(riffGroupBoxLayout);
+  tag3Layout->addWidget(riffGroupBox);
+  tag3Layout->addStretch();
+
   QWidget* tag1AndTag2Page = new QWidget;
   QVBoxLayout* tag1AndTag2Layout = new QVBoxLayout(tag1AndTag2Page);
   QString tagFormatTitle(tr("&Tag Format"));
@@ -233,7 +253,8 @@ QWidget* ConfigDialogPages::createTagsPage()
     tagsTabWidget->addTab(tag1Page, tr("Tag &1"));
   }
   tagsTabWidget->addTab(tag2Page, tr("Tag &2"));
-  tagsTabWidget->addTab(tag1AndTag2Page, tr("Tag 1 a&nd Tag 2"));
+  tagsTabWidget->addTab(tag3Page, tr("Tag &3"));
+  tagsTabWidget->addTab(tag1AndTag2Page, tr("All Ta&gs"));
   tagsTabWidget->setCurrentIndex(1);
   vlayout->addWidget(tagsTabWidget);
   return tagsPage;
@@ -515,6 +536,7 @@ void ConfigDialogPages::setConfigs(
   }
   m_pictureNameComboBox->setCurrentIndex(tagCfg.pictureNameIndex());
   m_genreNotNumericCheckBox->setChecked(tagCfg.genreNotNumeric());
+  m_lowercaseId3ChunkCheckBox->setChecked(tagCfg.lowercaseId3RiffChunk());
   m_textEncodingV1ComboBox->setCurrentIndex(tagCfg.textEncodingV1Index());
   m_textEncodingComboBox->setCurrentIndex(tagCfg.textEncoding());
   m_id3v2VersionComboBox->setCurrentIndex(
@@ -522,6 +544,13 @@ void ConfigDialogPages::setConfigs(
   m_trackNumberDigitsSpinBox->setValue(tagCfg.trackNumberDigits());
   m_markOversizedPicturesCheckBox->setChecked(tagCfg.markOversizedPictures());
   m_maximumPictureSizeSpinBox->setValue(tagCfg.maximumPictureSize());
+  idx = m_trackNameComboBox->findText(tagCfg.riffTrackName());
+  if (idx >= 0) {
+    m_trackNameComboBox->setCurrentIndex(idx);
+  } else {
+    m_trackNameComboBox->addItem(tagCfg.riffTrackName());
+    m_trackNameComboBox->setCurrentIndex(m_trackNameComboBox->count() - 1);
+  }
   m_browserLineEdit->setText(networkCfg.browser());
   m_playOnDoubleClickCheckBox->setChecked(guiCfg.playOnDoubleClick());
   m_proxyCheckBox->setChecked(networkCfg.useProxy());
@@ -627,6 +656,7 @@ void ConfigDialogPages::getConfig() const
   tagCfg.setCommentName(m_commentNameComboBox->currentText());
   tagCfg.setPictureNameIndex(m_pictureNameComboBox->currentIndex());
   tagCfg.setGenreNotNumeric(m_genreNotNumericCheckBox->isChecked());
+  tagCfg.setLowercaseId3RiffChunk(m_lowercaseId3ChunkCheckBox->isChecked());
   tagCfg.setTextEncodingV1Index(m_textEncodingV1ComboBox->currentIndex());
   tagCfg.setTextEncoding(m_textEncodingComboBox->currentIndex());
   tagCfg.setId3v2Version(m_id3v2VersionComboBox->itemData(
@@ -634,6 +664,7 @@ void ConfigDialogPages::getConfig() const
   tagCfg.setTrackNumberDigits(m_trackNumberDigitsSpinBox->value());
   tagCfg.setMarkOversizedPictures(m_markOversizedPicturesCheckBox->isChecked());
   tagCfg.setMaximumPictureSize(m_maximumPictureSizeSpinBox->value());
+  tagCfg.setRiffTrackName(m_trackNameComboBox->currentText());
   networkCfg.setBrowser(m_browserLineEdit->text());
   guiCfg.setPlayOnDoubleClick(m_playOnDoubleClickCheckBox->isChecked());
   networkCfg.setUseProxy(m_proxyCheckBox->isChecked());
